package co.uk.wobblycogs.samplefx5;

import java.net.URL;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.ResourceBundle;
import javafx.application.Platform;
import javafx.beans.property.SimpleStringProperty;
import javafx.concurrent.Task;
import javafx.fxml.FXML;
import javafx.fxml.Initializable;
import javafx.scene.control.Label;

/**
 *
 * @author Graham Smith
 */
public class LabelUpdateController implements Initializable {

	public static final String FRIENDLY_NAME = "Label Update";
	public static final String NAME = "uk.co.wobblycogs.samplefx5.LabelUpdate";
	public static final String FXML_RESOURCE = "/resources/fxml/LabelUpdate.fxml";
	@FXML
	private Label timeDisplayLabel;
	@FXML
	private Label dynamicTimeDisplayLabel;
	@FXML
	private Label dynamicTimeDisplayLabel2;
	private SimpleStringProperty timeProperty = new SimpleStringProperty();
	private SimpleStringProperty dynamicTimeProperty = new SimpleStringProperty();

	public LabelUpdateController() {
	}

	@Override
	public void initialize(URL url, ResourceBundle rb) {
		//Label showing the time, this label is updated one but could be updated
		//against from the JavaFX thread via the property.
		timeDisplayLabel.textProperty().bind(timeProperty);
		SimpleDateFormat sdf = new SimpleDateFormat("HH:mm:ss");
		timeProperty.set(sdf.format(new Date()));

		//A label showing the time which updates dynamically. Old school runnable
		//in a thread using run later to update the UI.
		dynamicTimeDisplayLabel.textProperty().bind(dynamicTimeProperty);
		Thread t = new Thread(new Runnable() {
			@Override
			public void run() {
				SimpleDateFormat sdf = new SimpleDateFormat("HH:mm:ss");
				while (true) {
					final String date = sdf.format(new Date());
					Platform.runLater(new Runnable() {
						@Override
						public void run() {
							dynamicTimeProperty.set(date);
						}
					});

					try {
						Thread.sleep(100);
					} catch (InterruptedException ex) {
						break;
					}
				}
			}
		});
		t.setName("Runnable Time Updater");
		t.setDaemon(true);
		t.start();

		//A more JavaFX style back ground thread which updates a label with the
		//current time. Since this is a Task the message property, which is
		//thread safe, is bound to the label.
		Task dynamicTimeTask = new Task<Void>() {
			@Override
			protected Void call() throws Exception {
				SimpleDateFormat sdf = new SimpleDateFormat("HH:mm:ss");
				while (true) {
					updateMessage(sdf.format(new Date()));

					try {
						Thread.sleep(100);
					} catch (InterruptedException ex) {
						break;
					}
				}
				return null;
			}
		};
		dynamicTimeDisplayLabel2.textProperty().bind(dynamicTimeTask.messageProperty());
		Thread t2 = new Thread(dynamicTimeTask);
		t2.setName("Tesk Time Updater");
		t2.setDaemon(true);
		t2.start();
	}
}
