/*
 * Copyright 2013 Graham Smith
 */
package co.uk.wobblycogs.samplefx5;

import java.io.IOException;
import java.net.URL;
import java.util.ResourceBundle;
import java.util.logging.Level;
import java.util.logging.Logger;
import javafx.event.ActionEvent;
import javafx.event.EventHandler;
import javafx.fxml.FXML;
import javafx.fxml.FXMLLoader;
import javafx.fxml.Initializable;
import javafx.scene.Node;
import javafx.scene.Scene;
import javafx.scene.control.Label;
import javafx.scene.control.Menu;
import javafx.scene.control.MenuBar;
import javafx.scene.control.MenuItem;
import javafx.scene.control.Tab;
import javafx.scene.control.TabPane;

/**
 *
 * @author Graham Smith
 */
public class SampleFX5Controller implements Initializable {

	@FXML
	private TabPane mainTabPane;
	@FXML
	private MenuBar mainMenuBar;

	@Override
	public void initialize(URL url, ResourceBundle rb) {
		find("showHideMenuItem").setOnAction(createHandler(ShowHideController.class));
		find("labelUpdateMenuItem").setOnAction(createHandler(LabelUpdateController.class));
	}

	private MenuItem find(String id) {
		MenuItem found = null;
		for (Menu m : mainMenuBar.getMenus()) {
			found = menuWalk(m, id);
			if (found != null) {
				break;
			}
		}
		return found;
	}

	private MenuItem menuWalk(Menu m, String id) {
		MenuItem found = null;
		for (MenuItem item : m.getItems()) {
			if (item.getId().equals(id)) {
				found = item;
				break;
			} else {
				if (item instanceof Menu) {
					found = menuWalk((Menu) item, id);
					if (found != null) {
						break;
					}
				}
			}
		}
		return found;
	}

	private TabCreator createHandler(Class controller) {
		try {
			String friendlyName = (String) controller.getDeclaredField("FRIENDLY_NAME").get(String.class);
			String name = (String) controller.getDeclaredField("NAME").get(String.class);
			String fxmlResource = (String) controller.getDeclaredField("FXML_RESOURCE").get(String.class);
			return new TabCreator(mainTabPane, friendlyName, name, fxmlResource);
		} catch (IllegalArgumentException | IllegalAccessException | NoSuchFieldException | SecurityException ex) {
			throw new IllegalArgumentException("Failed to create handler. Unable to extract tool name and resource from the given class: " + controller.getName(), ex);
		}
	}
}
