package co.uk.wobblycogs.samplefx5;

import java.net.URL;
import java.util.ResourceBundle;
import javafx.beans.value.ChangeListener;
import javafx.beans.value.ObservableValue;
import javafx.event.ActionEvent;
import javafx.fxml.FXML;
import javafx.fxml.Initializable;
import javafx.scene.control.TitledPane;
import javafx.scene.control.ToggleButton;
import javafx.scene.layout.VBox;

/**
 *
 * @author Graham Smith
 */
public class ShowHideController implements Initializable {

	public static final String FRIENDLY_NAME = "Show / Hide";
	public static final String NAME = "uk.co.wobblycogs.samplefx5.ShowHide";
	public static final String FXML_RESOURCE = "/resources/fxml/ShowHide.fxml";
	@FXML
	private TitledPane pane2;
	@FXML
	private ToggleButton pane2Toggle;
	@FXML
	private TitledPane pane3;
	@FXML
	private ToggleButton pane3Toggle;
	@FXML
	private TitledPane pane4;
	@FXML
	private ToggleButton pane4Toggle;
	@FXML
	private VBox togglePaneParent;
	private int pane3Position;

	public ShowHideController() {
	}

	@Override
	public void initialize(URL url, ResourceBundle rb) {
		//*** Binding the Managed Property ***
		//This is the best way to hide part of the scene. Bind the managed
		//property of the pane to it's visible property. An unmanaged pane
		//will not take up space in the layout and cause the other items
		//on the page to re-flow. If and item is managed it will take up
		//space whether it's visibile or not. It is necessary to make it
		//both unmanaged and invisible to stop it from hiding showing through
		//if the other items being displayed don't cover it completely.
		pane2.managedProperty().bind(pane2.visibleProperty());
		pane2.visibleProperty().bind(pane2Toggle.selectedProperty());

		//*** Removing the Child ***
		//This is an acceptable way to hide part of the scene if the above
		//method is difficult for some reason. The main downside of this
		//method is that you need to record the location of the pane in the
		//parent pane. Obviously if it's the last item or you don't care where
		//it appears this isn't such an issue but generally you'll need to be
		//careful about where it gets put back into the scene.
		pane3Toggle.selectedProperty().addListener(new ChangeListener<Boolean>() {
			@Override
			public void changed(ObservableValue<? extends Boolean> ov, Boolean oldValue, Boolean newValue) {
				if (newValue) {
					togglePaneParent.getChildren().add(pane3Position, pane3);
				} else {
					pane3Position = togglePaneParent.getChildren().indexOf(pane3);
					togglePaneParent.getChildren().remove(pane3);
				}
			}
		});

		//*** Setting the Size to Zero ***
		//This is a terrible method for hiding a node in the scene because it
		//requires you to potentially keep track of numeroud different
		//variables. In this example I'm mostly letting the layout engine get
		//on with it but if you had a layout that relied on carefully sized
		//nodes you'd potentially need to remember min, pref and max width and
		//height. The only real benefit is that because the node isn't removed
		//from it's parent there's no problems re-inserting it into the scene.
		pane4Toggle.selectedProperty().addListener(new ChangeListener<Boolean>() {
			@Override
			public void changed(ObservableValue<? extends Boolean> ov, Boolean oldValue, Boolean newValue) {
				if (newValue) {
					pane4.setMaxSize(Double.MAX_VALUE, Double.MAX_VALUE);
				} else {
					pane4.setMaxSize(0, 0);
					pane4.setMinSize(0, 0);
				}
			}
		});
	}
}
